# LASPrs: Library for Acoustic Signal Processing in Rust

Welcome to LASPrs: Library for Acoustic Signal Processing. LASPrs is a rust 
library that provides tools and measurement software that enables the acquisition
and processing of (multi) sensor data in real time on a PC and output results.

## Note to potential users

**This crate is still under heavy development. API changes happen on the fly. Documentation is not finished. Use with caution but except things to be broken and buggy.**

## Documentation

Documentation is provided at [doc.rs](https://docs.rs/lasprs/latest/lasprs).


## Python bindings and examples

The library has Python bindings (via [pyo3](https://pyo3.rs), which can be installed via:

```
$ pip install git+https://code.ascee.nl/ascee/lasprs --install-option "python-bindings"
```

